#

#####

`import numpy as np
x, y = np.meshgrid(np.linspace(-2, 2, 20), np.linspace(-2, 2, 20))
z = x**2 + y**2
ashaxiom.Axiom.start(z).plot3D(x, y)`

#####

`#
t1 = brain.solve("market", ticker="INTC", period="1y").lazy()
t2 = brain.solve("market", ticker="AMD", period="1y").lazy()
results = brain.add(t1, t2).threadingOn(2)
#
spread = ashaxiom.Axiom.start(results[0]).subtract(results[1])
#
report = spread.annual_report().precision(2)
display(report)`